#!/usr/bin/env bash

# Generic file handling routine
# Takes filename as only argument
function handle()
{
  FILE=$1
  # create the .orig if need be (so .orig is the link to repos)
  if [ ! -s $FILE.orig ]; then
     mv $FILE $FILE.orig;
  fi
  # if orig has changed or $FILE is not there, regenerate $FILE 
  if [ \( ! -e $FILE \) -o \( $FILE.orig -nt $FILE \) ]; then
     ./setup_reorder.py --input=$FILE.orig --output=$FILE --auto;
  fi
}

function unhandle()
{
  FILE=$1
  # remove $FILE and move .orig to $FILE

  # no original file, nothing to do
  if [ ! -s $FILE.orig ]; then
     return;
  fi

  # if new file exists remove it
  if [ -s $FILE ]; then
     rm -f $FILE 2>/dev/null;
  fi

  # now move the file over
  mv $FILE.orig $FILE
}

# list of files to be processed

FILELIST='%(reordlist)s'

OPTION=$1

if [ -z $OPTION ]; then
   for m in $FILELIST; do
       handle $m;
   done;
elif [ "$OPTION" == "--clean" ]; then
   for m in $FILELIST; do
       unhandle $m;
   done;
else
   echo "Unknown option: [$OPTION]"
   exit 1;
fi

