!!****if* source/Driver/DriverMain/Driver_abortFlash
!!
!! NAME
!!
!!  Driver_abortFlash
!!
!! SYNOPSIS
!!
!!  Driver_abortFlash(character(len=*)(IN) :: errorMessage)
!!
!! DESCRIPTION
!!
!!  Write an error message to the logfile and abort FLASH.
!!  Attempts to shut down all processes (using MPI_Abort()).
!!  If you wish to call Driver_abortFlash from a 'c' routine
!!  use the API function Driver_abortFlashC
!!
!!
!! ARGUMENTS
!!
!!  errorMessage -    A string to write to the logfile (presumably 
!!                    indicating what went wrong).
!!
!!***

subroutine Driver_abortFlash (errorMessage)
  
  use Driver_data, ONLY : dr_myPE
  use Logfile_interface, ONLY : Logfile_stampMessage, Logfile_close

  implicit none

  include "Flash_mpi.h"
#include "constants.h"          
#include "Flash.h"

  character(len=*), intent(in) :: errorMessage
  character(len=MAX_STRING_LENGTH*2) :: errorMessagePlusAbort
  logical, parameter :: forceYes = .true. 

  ! To be passed to MPI_Abort
  integer, parameter::      errcode = 1
  integer :: ierr

  ! Use to generate a message giving the processor #.
  character(len=MAX_STRING_LENGTH):: peMessage = &
            & "[DRIVER_ABORT] Driver_abort() called by PE "


  if (dr_myPE .eq. MASTER_PE) then
     print *, " "
     print *, "Driver_abort called. See log file for details."
     print *, "Error message is ", errorMessage  
     print *, "Calling MPI_Abort() for immediate shutdown!"
     print  *, ''
  end if

  write (peMessage(len_trim(peMessage)+1:), *) dr_myPE

  ! make a complete string out of error message
  errorMessagePlusAbort = "abort_message " // errorMessage
  
!  call Logfile_stamp (dr_myPE, peMessage, "[DRIVER_ABORT]")
!  call Logfile_stamp (dr_myPE, errorMessage, "abort_message")
  call Logfile_stampMessage (dr_myPE, peMessage, forceYes)
  call Logfile_stampMessage (dr_myPE, errorMessagePlusAbort, forceYes)
  call Logfile_close (dr_myPE)

  call MPI_Abort (MPI_COMM_WORLD, errcode, ierr)
  stop            ! should not make it here

  return
end subroutine Driver_abortFlash
