!!****h* source/Driver/Driver_interface
!!
!! NAME
!!  Driver_interface
!!
!! SYNOPSIS
!!
!!  use  Driver_interface
!!
!! DESCRIPTION
!!
!! This is the header file for the Driver module
!! that defines its public interfaces.
!!***
Module Driver_interface
 
  implicit none

# include "Flash.h"
# include "constants.h"

  interface
    subroutine Driver_abortFlash (errorMessage)
      implicit none
      character(len=*), intent(in) :: errorMessage
    end subroutine Driver_abortFlash
  end interface

  interface
    subroutine Driver_computeDt(myPE, numProcs,  &
                        nbegin, nstep, &
                        simTime, dtOld, dtNew)
      implicit none
      integer, intent(IN) :: myPE, numProcs
      integer, intent(IN) :: nbegin, nstep
      real,    intent(IN) :: simTime    !! current simulation time
      real, intent(IN) :: dtOld      !! last time step we used
      real, intent(OUT):: dtNew      !! the new timestep we get. to be returned.
    end subroutine Driver_computeDt
  end interface

  interface
    subroutine Driver_evolveFlash()
      implicit none
    end subroutine Driver_evolveFlash
  end interface

  interface
    subroutine Driver_finalizeFlash()
      implicit none
    end subroutine Driver_finalizeFlash
  end interface

  interface
    subroutine Driver_finalizeSourceTerms(myPE, restart)
      implicit none
      integer, intent(in) :: myPE
      logical, intent(in) :: restart
    end subroutine Driver_finalizeSourceTerms
  end interface

  interface
    subroutine Driver_getDt(dt)
      implicit none
      real, intent(out) :: dt
    end subroutine Driver_getDt
  end interface

  interface
    subroutine Driver_getElapsedWCTime(elapsedWCTime)
      implicit none
      real, intent(out) :: elapsedWCTime
    end subroutine Driver_getElapsedWCTime
  end interface

  interface
    subroutine Driver_getNStep(nstep)
      implicit none
      integer, intent(out) :: nstep
    end subroutine Driver_getNStep
  end interface

  interface
    subroutine Driver_getSimTime(simulationTime)
      implicit none
      real, intent(out) :: simulationTime
    end subroutine Driver_getSimTime
  end interface

  interface
    subroutine Driver_init(myPE)
      implicit none
      integer, intent(in) :: myPE
    end subroutine Driver_init
  end interface

  interface
    subroutine Driver_initFlash()
      implicit none
    end subroutine Driver_initFlash
  end interface

  interface
    subroutine Driver_initMaterialProperties(myPE)
      implicit none
      integer, intent(IN) :: myPE
    end subroutine Driver_initMaterialProperties
  end interface

  interface
    subroutine Driver_initParallel (myPE, numProcs)
      implicit none
      integer, intent(out) :: myPE, numProcs
    end subroutine Driver_initParallel
  end interface

  interface
    subroutine Driver_initSourceTerms(myPE, restart)
      implicit none
      integer, intent(in) :: myPE
      logical, intent(in) :: restart
    end subroutine Driver_initSourceTerms
  end interface

  interface
    subroutine Driver_sendOutputData()
      implicit none
    end subroutine Driver_sendOutputData
  end interface

  interface
    subroutine Driver_sourceTerms(blockCount, blockList, dt) 
      implicit none
      real, intent(IN)    :: dt
      integer, intent(IN) :: blockCount
      integer, dimension(blockCount), intent(IN):: blockList
    end subroutine Driver_sourceTerms
  end interface

  interface
    subroutine Driver_verifyInitDt(myPE)
      implicit none
      integer, intent(in) :: myPE
    end subroutine Driver_verifyInitDt
  end interface

  interface
     subroutine Driver_getTimeStamp(dateStr)
       implicit none
       character(len=40), intent(OUT)     :: dateStr
     end subroutine Driver_getTimeStamp
  end interface

  interface
     subroutine Driver_putTimeStamp(dateStr)
       implicit none
       character(len=40), intent(IN)     :: dateStr
     end subroutine Driver_putTimeStamp
  end interface

end Module Driver_interface
