!!****f* source/Grid/Grid_moveParticles
!!
!! NAME
!!  Grid_moveParticles
!!
!! SYNOPSIS
!!
!!  Grid_moveParticles(real(INOUT)    :: particles(:,:),
!!                     integer(INOUT) :: localNumParticles,
!!                     integer(IN)    :: maxParticlesPerProc)
!!
!!                    
!!  
!! DESCRIPTION 
!!  
!!  Move data corresponding to the  particles that have moved to a different block 
!!  or processor number.
!!  
!!  The Uniform Grid and AMR versions of this routine have different implementations, but
!!  in general, if a particle has moved off the current block, this routine physically
!!  moves that particle's data structure from the old block to the new block. Since UG has
!!  only one block per processor, this translates into moving the data to another processors.
!!  With AMR, the move could be to another block within the same processor, or to a 
!!  block on another processor.
!!
!!  For details on the specifics of the algorithm check the documentation for your specific
!!  implementation.
!!
!!  This routine works for both active and passive particles.
!! 
!!  
!! ARGUMENTS 
!!
!!  particles : List of particles. It is two dimensional real array, the first dimension
!!              represents each particle's properties, and second dimension is index to
!!              particles.
!!
!!  localNumParticles : While coming in it contains the current number of particles mapped to
!!                      this processor. After all the data structure movement, the number
!!                      of local particles might change, and the new value is put back into it
!!
!!  maxParticlesPerProc : This is parameter determined at runtime, and is the maximum number of loca
!!                        particles that a simulation expects to have. All the arrays in the particles
!!                        unit are allocated based on this number
!!
!!
!!***



subroutine Grid_moveParticles(particles,localNumParticles,maxParticlesPerProc)
  implicit none
#include "constants.h"
#include "Flash.h"

  integer,intent(INOUT) :: localNumParticles
  integer, intent(IN) :: maxParticlesPerProc

  real,intent(INOUT),dimension(NPART_PROPS,maxParticlesPerProc)::particles

end subroutine Grid_moveParticles
