!!****f* source/Grid/Grid_moveParticlesGlobal
!!
!! NAME
!!  Grid_moveParticlesGlobal
!!
!! SYNOPSIS
!!
!!  Grid_moveParticlesGlobal(real(INOUT)    :: particles(:,:),
!!                                integer(INOUT) :: localNumParticles,
!!                                integer(IN)    :: maxParticlesPerProc)
!!  
!! DESCRIPTION 
!!  
!!  This routine moves particles to the correct block and processor
!!  globally. Unlike Grid_moveParticles, which assumes that particles
!!  move only to their neighboring blocks, this routines makes no
!!  assumptions about the source and destination blocks of the 
!!  particles. It makes sure that physical coordinates of each particle 
!!  fall within the bound box of the block it is associated with.
!!
!!
!! ARGUMENTS 
!!
!!  particles : List of particles. It is two dimensional real array, the first dimension
!!              represents each particle's properties, and second dimension is index to
!!              particles.
!!
!!  localNumParticles : While coming in it contains the current number of particles mapped to
!!                      this processor. After all the data structure movement, the number
!!                      of local particles might change, and the new value is put back into it
!!  maxParticlesPerProc : This is parameter determined at runtime, and is the maximum number of loca
!!                        particles that a simulation expects to have. All the arrays in the particles
!!                        unit are allocated based on this number
!!
!!
!! NOTES
!!   
!!
!!
!!
!!
!!***

subroutine Grid_moveParticlesGlobal(particles,&
                                       localNumParticles,maxParticlesPerProc)
 
  implicit none
#include "Flash.h"
  integer,intent(INOUT):: localNumParticles
  integer, intent(IN) :: maxParticlesPerProc
  real,dimension(NPART_PROPS,maxParticlesPerProc),intent(INOUT) :: particles

end subroutine Grid_moveParticlesGlobal


