!!****f* source/Grid/Grid_sortParticles
!!
!! NAME
!!  Grid_sortParticles
!!
!! SYNOPSIS
!!
!!  Grid_sortParticles(real(INOUT) :: particles(:,:),
!!                     integer(IN) :: props
!!                   integer(IN)   :: localNumParticles,
!!                   integer(IN)   :: particleTypes,
!!                   integer(IN)   :: maxParticlesPerProc,
!!                   integer(OUT)  :: particlesPerBlk(:,:),
!!            optional,logical(IN) :: partType)
!!                    
!!  
!! DESCRIPTION 
!!  
!!  Sorts the particles by block number.  
!! 
!!
!! ARGUMENTS 
!!
!!  particles : List of particles. It is two dimensional real array, the first dimension
!!              represents each particle's properties, and second dimension is index to
!!              particles.
!!
!!  props : number of properties in the particles datastructure
!!
!!  localNumParticles : While coming in it contains the current number of particles mapped to
!!                      this processor. After all the data structure movement, the number
!!                      of local particles might change, and the new value is put back into it
!!     particleTypes : count of the type of particles, types could be passive
!!                     active or some other type defined by the user
!!
!!  maxParticlesPerProc : This is parameter determined at runtime, and is the maximum number of loca
!!                        particles that a simulation expects to have. All the arrays in the particles
!!                        unit are allocated based on this number
!! particlesPerBlk : integer array containing number of particles on each blk.
!! partType : If present make sure that the particles are sorted on their
!!            type upon exit. The types can be passive or active, of some
!!            other type defined by the user
!!
!! NOTES 
!!   currently this routine is called only by io_writeParticles in permanent guardcell mode,
!!   and by the routines that map mesh to particles in non-permanent-guardcell mode.
!!
!!***
subroutine Grid_sortParticles(particles,props,localNumParticles,&
     particleTypes, maxPerProc, particlesPerBlk,partType)

  implicit none
#include "Flash.h"
  integer,intent(IN) :: localNumParticles, maxPerProc,props,particleTypes
  integer,intent(INOUT),dimension(props,maxPerProc) :: particles
  integer,intent(OUT),dimension(MAXBLOCKS,particleTypes) :: particlesPerBlk
  logical,optional,intent(IN) :: partType
  particlesPerBlk=0
  return
end subroutine Grid_sortParticles
