!!****ih* source/Grid/localAPI/gr_interface
!!
!! NAME
!!
!!  gr_interface
!!
!! SYNOPSIS
!!
!!  use gr_interface
!!
!! DESCRIPTION
!!
!!  Interfaces for some subprograms private to the GridMain subunit.
!!
!!  Currently, these are mostly subprograms used in the PARAMESH3/4 Grid implementations.
!!
!!***

! Modification history:
!     Created gr_flashWithPM3_interfaces          February 2007  KW
!     Renamed gr_pm3Interface                     January  2008  AD
!     Renamed gr_interface and moved to localAPI  June     2008  KW
!     Added gr_findMean, alphabetized functions   July     2008  LBR

module gr_interface
#include "constants.h"
  implicit none

  interface
     integer function gr_extractBCForDirection(packedBCs,axis,leftOrRight)
     ! implementation in GridMain/paramesh/paramesh4/gr_packBCs.F90
       implicit none
       integer,intent(IN) :: packedBCs,axis,leftOrRight
     end function gr_extractBCForDirection
  end interface

  interface
     subroutine gr_findBlock(blkList,blkCount,pos,blockID)
       implicit none
       integer,intent(IN) :: blkCount
       integer,dimension(blkCount),intent(IN) :: blkList
       real,dimension(MDIM),intent(IN) :: pos
       integer,intent(OUT) :: blockID
     end subroutine gr_findBlock
  end interface

  interface
     subroutine gr_findMean(iSrc, iType, bGuardcell, mean)
       implicit none
       integer, intent(in) :: iSrc, iType
       logical, intent(in) :: bGuardcell
       real, intent(out) :: mean
     end subroutine gr_findMean
  end interface

  interface
     subroutine gr_findWhichChild(pos,blockID,Negh,whichChild)
       implicit none
       real,dimension(MDIM), intent(IN) :: pos
       integer,intent(IN) :: blockID
       integer, dimension(MDIM),intent(IN) :: Negh
       integer, intent(OUT) :: whichChild
     end subroutine gr_findWhichChild
  end interface

  interface
     subroutine gr_findNeghID(blockID,pos,Negh,neghID)
       implicit none
       integer,intent(IN) :: blockID
       real,dimension(MDIM), intent(IN) :: pos
       integer,dimension(MDIM),intent(IN) :: Negh
       integer,dimension(BLKNO:PROCNO),intent(OUT) :: neghID
     end subroutine gr_findNeghID
  end interface

  interface
     subroutine gr_getBlkHandle(remoteBlockID, pe, blockHandle)
     ! implementation in GridMain/paramesh
       implicit none
       integer, intent(in) :: remoteBlockID, pe
       integer, intent(INOUT) :: blockHandle
     end subroutine gr_getBlkHandle
  end interface

  interface
     integer function gr_packBCs(bcILeft, bcIRight, bcJLeft, bcJRight, bcKLeft, bcKRight)
     ! implementation in GridMain/paramesh/paramesh4
       implicit none
       integer,intent(IN) :: bcILeft, bcIRight, bcJLeft, bcJRight, bcKLeft, bcKRight
     end function gr_packBCs
  end interface
  
  interface
     subroutine gr_setGcFillNLayers(layers, idir, guard, minLayers)
     ! implementation in GridMain/paramesh
       implicit none
       integer,dimension(MDIM), intent(OUT) :: layers
       integer, intent(IN)  :: idir, guard
       integer, intent(IN),OPTIONAL  :: minLayers
     end subroutine gr_setGcFillNLayers
  end interface

  interface
     subroutine gr_neghAtSameLevel(blockID,atSameLevel)
       integer,intent(IN) :: blockID
       logical,dimension(LEFT_EDGE:RIGHT_EDGE,&
            LEFT_EDGE:RIGHT_EDGE,&
            LEFT_EDGE:RIGHT_EDGE),intent(OUT) :: atSameLevel
       
     end subroutine gr_neghAtSameLevel
  end interface

  interface
     subroutine gr_sanitizeDataAfterInterp(blkList,count, info, layers)
       integer,intent(IN) :: count
       integer, dimension(count), intent(IN) :: blkList
       character(len=*), intent(IN) :: info
       integer, dimension(MDIM), intent(IN):: layers
     end subroutine gr_sanitizeDataAfterInterp
  end interface


end module gr_interface
