!!****ih* source/Grid/localAPI/gr_pfftInterface
!!
!! NAME 
!!   gr_pfftInterface
!!
!! SYNOPSIS
!!   
!!   use gr_pfftInterface
!!
!! DESCRIPTION
!! 
!!  This is the header file for the Pfft solver that defines its
!!  interfaces.
!!
!!***

module gr_pfftinterface
#include "constants.h"
  implicit none

  interface
     subroutine gr_pfftInit()
     end subroutine gr_pfftInit
  end interface

  interface
     subroutine gr_pfftFinalize()
     end subroutine gr_pfftFinalize
  end interface

  interface
     subroutine gr_pfftDcftForward(inArray,outArray,trig,len,lda,numVec,&
          transformType,scale)
       integer, intent(IN) :: len, lda, numVec, transformType
       real, intent(IN) :: scale
       real, dimension(:),intent(IN) :: trig,inArray
       real,dimension(:), intent(OUT) :: outArray
     end subroutine gr_pfftDcftForward
  end interface
  
  interface
     subroutine gr_pfftDcftInverse(inArray,outArray,trig,len,lda,numVec,&
          transformType,scale)
       integer, intent(IN) :: len, lda, numVec, transformType
       real, intent(IN) :: scale
       real, dimension(:),intent(IN) :: trig,inArray
       real,dimension(:), intent(OUT) :: outArray
     end subroutine gr_pfftDcftInverse
  end interface

  interface
     subroutine gr_pfftDisperse(inArray,outArray,nx,ny,nx1)
       integer,intent(IN) :: nx,ny,nx1
       real,intent(IN),dimension(:) :: inArray
       real,intent(OUT), dimension(:) :: outArray
     end subroutine gr_pfftDisperse
  end interface

  interface
     subroutine gr_pfftGenMap()
     end subroutine gr_pfftGenMap
  end interface

  interface
     subroutine gr_pfftInitMetaData(ndim)
       integer, intent(IN) :: ndim
     end subroutine gr_pfftInitMetaData
  end interface
  
  interface
     subroutine gr_pfftIntersperse(inArray,outArray,nx,ny,nx1)
       integer, intent(IN) :: nx,ny,nx1
       real,dimension(:), intent(IN) :: inArray
       real,dimension(:), intent(OUT) :: outArray
     end subroutine gr_pfftIntersperse
  end interface

  interface
     subroutine gr_pfftLocalTranspose(inArray,outArray,nx,nx1,type)
       integer,intent(IN) :: nx,nx1,type
       real,intent(IN),dimension(:) :: inArray
       real,intent(OUT), dimension(:) :: outArray
     end subroutine gr_pfftLocalTranspose
  end interface

  interface
     subroutine gr_pfftSetupDim(length, transformType, trig, scale, factor)
       integer,intent(IN) :: length,transformType
       real,dimension(:), pointer :: trig
       real,intent(OUT) :: scale
       integer,intent(OUT) :: factor
     end subroutine gr_pfftSetupDim
  end interface
  
  interface
     subroutine gr_pfftTranspose(dir,type,inArray,outArray,inlen,outlen,pr,comm)
       integer, intent(IN) :: pr,comm,dir,type
       integer, dimension(MDIM), intent(IN) :: inlen,outlen
       real,dimension(:),intent(INOUT) :: inArray,outArray
     end subroutine gr_pfftTranspose
  end interface

  interface
     subroutine gr_pfftGetLocalLimits(axis1,axis2)
       integer,intent(IN) :: axis1, axis2
     end subroutine gr_pfftGetLocalLimits
  end interface


  interface
     subroutine gr_pfftWave()
     end subroutine gr_pfftWave
  end interface

  interface
     subroutine gr_pfftDerivs(transArray)
       real,dimension(:),intent(INOUT) :: transArray
     end subroutine gr_pfftDerivs
  end interface
  
  interface
     subroutine gr_pfftGetProcGrid(totalProcs)
       integer, intent(IN) :: totalProcs
     end subroutine gr_pfftGetProcGrid
  end interface


  interface
     subroutine gr_pfftGenMapHelper(axis, fragmentPtr, maxSingleProcData)
       integer, intent(IN) :: axis
       integer, dimension(:), intent(IN) :: fragmentPtr
       integer, intent(OUT) :: maxSingleProcData
     end subroutine gr_pfftGenMapHelper
  end interface

  !Unable to specify intent for "buffer" and "pfftArray".  This is because
  !sometimes the procedure is called with "pfftArray" which is an intent(IN)
  !in the calling subroutine, and sometimes "pfftArray" is an intent(OUT) in the
  !calling subroutine.  Specifying intent(INOUT) does not work.
  interface
     subroutine gr_pfftBufferTransfer(direction, axis, buffer, pfftArray)
       integer, intent(IN) :: direction, axis
       real, dimension(:,:) :: buffer
       real, dimension(:) :: pfftArray       
     end subroutine gr_pfftBufferTransfer
  end interface

  interface
     subroutine gr_pfftGetDestPfftCoords(startPos, pfftProcCoords)       
       implicit none
       integer, dimension(1:MDIM), intent(IN) :: startPos
       integer, dimension(1:MDIM), intent(OUT) :: pfftProcCoords
     end subroutine gr_pfftGetDestPfftCoords
  end interface

  interface
     subroutine gr_pfftCopyToSendMap(blockID, blockStartPos, blockEndPos, bsize, axis)
       implicit none
       integer, intent(IN) :: blockID
       integer, dimension(1:MDIM), intent(IN) :: blockStartPos, blockEndPos
       integer, intent(IN) :: bsize, axis
     end subroutine gr_pfftCopyToSendMap
  end interface

  interface
     subroutine gr_pfftHandleJaxisFragments(direction, gridVar)
       implicit none
       integer, intent(IN) :: direction, gridVar
     end subroutine gr_pfftHandleJaxisFragments
  end interface

  interface
     subroutine gr_pfftHandleKaxisFragments(direction)
       implicit none
       integer, intent(IN) :: direction
     end subroutine gr_pfftHandleKaxisFragments
  end interface

  interface
     subroutine gr_pfftPrintCommBuffers(buffer, map, logUnit)       
       implicit none
       real, dimension(:,:), intent(IN) :: buffer
       integer, dimension(:,:), intent(IN) :: map
       integer, intent(IN) :: logUnit
     end subroutine gr_pfftPrintCommBuffers
  end interface

  interface
     subroutine gr_pfftGroupUsableProcesses(myPE, globalProcs, originalComm, newComm)
       implicit none
       integer, intent(IN) :: myPE, globalProcs, originalComm
       integer, intent(OUT) :: newComm
     end subroutine gr_pfftGroupUsableProcesses
  end interface

  interface
     subroutine gr_pfft3Dto1D(pfftArray, p3dArray)
       implicit none
       real, dimension(:), intent(INOUT) :: pfftArray
       real, pointer, dimension(:,:,:) :: p3dArray
     end subroutine gr_pfft3Dto1D
  end interface

  interface
     subroutine gr_pfft1Dto3D(inputArray, gridState, desiredLen, &
          complexData, p3Darray)
       implicit none
       real, dimension(:), intent(IN) :: inputArray
       character(len=*), intent(IN) :: gridState
       integer, dimension(MDIM), intent(IN) :: desiredLen
       logical, intent(IN) :: complexData
       real, pointer, dimension(:,:,:) :: p3Darray
     end subroutine gr_pfft1Dto3D
  end interface

  interface
     subroutine gr_pfft2Dto1D(pfftArray, p2dArray)       
       implicit none
       real, dimension(:), intent(INOUT) :: pfftArray
       real, pointer, dimension(:,:) :: p2dArray
     end subroutine gr_pfft2Dto1D
  end interface

  interface
     subroutine gr_pfft1Dto2D(inputArray, gridState, desiredLen, &
          complexData, p2Darray)
       implicit none
       real, dimension(:), intent(IN) :: inputArray
       character(len=*), intent(IN) :: gridState
       integer, dimension(MDIM), intent(IN) :: desiredLen
       logical, intent(IN) :: complexData
       real, pointer, dimension(:,:) :: p2Darray
     end subroutine gr_pfft1Dto2D
  end interface

 interface
     subroutine gr_pfftGetLocalLimitsAnytime(axis1,axis2,meaxis,&
          currentGridShape,isComplex,currentLocalLimits)
       implicit none
       integer,intent(IN) :: axis1, axis2, meaxis
       integer, intent(IN), dimension(MDIM) :: currentGridShape
       logical, intent(IN) :: isComplex
       integer, intent(INOUT), dimension(LOW:HIGH,MDIM) :: currentLocalLimits
     end subroutine gr_pfftGetLocalLimitsAnytime
  end interface

  interface
     subroutine gr_pfftPoissonDirect (iDirection, solveflag, inSize, &
          localSize, globalSize, transformType, inArray, outArray)
       integer, intent(in)    :: iDirection, solveflag, inSize  
       integer, dimension(MDIM),intent(in) :: localSize,globalSize,transformType
       real,  dimension(inSize),intent(in) :: inArray
       real,dimension(inSize), intent(out) :: outArray
     end subroutine gr_pfftPoissonDirect
  end interface

end module gr_pfftinterface
