!!****h* source/monitors/Logfile/Logfile_interface
!!
!! This is the header file for the Logfile module
!! that defines its public interfaces.
!!***
Module Logfile_interface

  implicit none

#include "Flash.h"
#include "constants.h"

  interface
    subroutine Logfile_break (myPE, char)
      integer, intent(in)                :: myPE
      character(len=1), intent(in)       :: char
    end subroutine Logfile_break
  end interface

  interface
    subroutine Logfile_close(myPE,local)
      integer, intent(IN) :: myPE
      logical,optional,intent(IN) :: local
    end subroutine Logfile_close
  end interface

  interface
    subroutine Logfile_create (myPE, numProcs)
      integer, intent(in)                :: myPE, numProcs
    end subroutine Logfile_create
  end interface

  interface
    subroutine Logfile_finalize()
    end subroutine Logfile_finalize
  end interface

  interface
    subroutine Logfile_init(myPE, numProcs)
      integer, intent(in) :: numProcs
      integer, intent(in) :: myPE
    end subroutine Logfile_init
  end interface

  interface
     subroutine Logfile_open(logUnit,logUnitLocal)
       integer,intent(OUT) :: logUnit
       logical,intent(IN) :: logUnitLocal
     end subroutine Logfile_open
  end interface
  
  interface Logfile_stamp
    subroutine Logfile_stampInt(myPE, intVal, tag, attrib)
      integer, intent(in)                   :: myPE, intVal  
      character(len=*), intent(in)           :: tag
      character(len=*), intent(in), OPTIONAL :: attrib
    end subroutine Logfile_stampInt

    subroutine Logfile_stampIntArray(myPE, intArr, len, tag, attrib)
      integer, intent(in)                   :: myPE  
      character(len=*),intent(in)           :: tag
      character(len=*), intent(in),OPTIONAL :: attrib
      integer,intent(in)                    :: len
      integer, dimension(len), intent(in)   :: intArr
    end subroutine Logfile_stampIntArray

    subroutine Logfile_stampReal(myPE, realVal, tag, attrib)
      integer, intent(in)                    :: myPE  
      real, intent(in)                       :: realVal
      character(len=*), intent(in)           :: tag
      character(len=*), intent(in), OPTIONAL  :: attrib
    end subroutine Logfile_stampReal

    subroutine Logfile_stampRealArray(myPE, realArr, len, tag, attrib)
      integer, intent(in)                    :: myPE  
      character(len=*),intent(in)            :: tag
      character(len=*), intent(in), OPTIONAL :: attrib
      integer,intent(in)                     :: len
      real, dimension(len),intent(in)        :: realArr
    end subroutine Logfile_stampRealArray

    subroutine Logfile_stampStr(myPE, string, tag, attrib)
      integer, intent(in)                    :: myPE  
      character(len=*), intent(in)           :: string
      character(len=*), intent(in), OPTIONAL :: tag, attrib
    end subroutine Logfile_stampStr

    subroutine Logfile_stampStrArray(myPE, strArr, len, tag, attrib)
      integer, intent(in)                      :: myPE  
      character(len=*), intent(in)             :: tag
      character(len=*), intent(in), OPTIONAL   :: attrib
      integer,intent(in)                       :: len
      character(len=*), dimension(len),intent(in) :: strArr
    end subroutine Logfile_stampStrArray

    subroutine Logfile_stampStrPair(myPE, strArr, len, dimen, tag, attrib)
      integer, intent(in)                   :: myPE  
      character(len=*),intent(in)           :: tag
      character(len=*),intent(in), OPTIONAL :: attrib
      integer,intent(in)                    :: len, dimen
      character(len=*),dimension(len,dimen),intent(in) :: strArr
    end subroutine Logfile_stampStrPair
  end interface

  interface
    subroutine Logfile_stampMessage(myPE, string,force)
      integer, intent(in)                    :: myPE  
      character(len=*), intent(in)           :: string
      logical, intent(in), optional          :: force
    end subroutine Logfile_stampMessage
  end interface

  interface
     subroutine Logfile_stampVarMask(unkVarMask, willCallEos, tag, maskTag)
       logical, intent(in) :: unkVarMask(NUNK_VARS)
       logical, intent(in) :: willCallEos
       character(len=*),intent(in) :: tag, maskTag
     end subroutine Logfile_stampVarMask
  end interface

  interface
    subroutine Logfile_writeSummary(myPE, strArr, length, dim, strLen, numHeaders,reduced,separateFiles)
      integer, intent(in)                      :: myPE
      integer, intent(in)                      :: length, dim, strLen, numHeaders
      character(len=MAX_STRING_LENGTH), dimension(length,dim), intent(in)  :: strArr
      logical, optional, intent(IN)                        :: reduced
      logical, optional, intent(IN)                        :: separateFiles
    end subroutine Logfile_writeSummary
  end interface

end Module Logfile_interface
