!!****h* source/physics/sourceTerms/Diffuse/Diffuse_interface
!!
!! NAME
!!   Diffuse_interface
!!
!! SYNOPSIS
!!   use Diffuse_interface,ONLY: Diffuse_init, Diffuse_therm, Diffuse_visc, Diffuse_computeDt
!!
!! DESCRIPTION
!! This is the header file for the diffuse module that defines its
!! public interfaces.
!!***
Module Diffuse_interface
#include "constants.h"
#include "Flash.h"

  interface
    subroutine Diffuse_computeDt (blockID, myPE, &
                                  xCenter,xLeft,xRight, dx, uxgrid, &
                                  yCenter,yLeft,yRight, dy, uygrid, &
                                  zCenter,zLeft,zRight, dz, uzgrid, &
                                  blkLimits,blkLimitsGC,        &
                                  solnData,   &
                                  dt_check, dt_minloc )
     

      integer, intent(IN) :: blockID, myPE
      integer, intent(IN),dimension(2,MDIM)::blkLimits,blkLimitsGC
      real,INTENT(INOUT)    :: dt_check
      integer,INTENT(INOUT)    :: dt_minloc(5)
      real, pointer, dimension(:,:,:,:) :: solnData

      real, dimension(blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS)), intent(IN) :: &
          xCenter,xLeft,xRight
      real, dimension(blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS)), intent(IN) :: &
           yCenter,yLeft,yRight
      real, dimension(blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)), intent(IN) ::&
           zCenter,zLeft,zRight
      real, dimension(blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS)), intent(IN) :: &
           dx, uxgrid
      real, dimension(blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS)), intent(IN) :: &
           dy, uygrid
      real, dimension(blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)), intent(IN) :: &
           dz, uzgrid
    end subroutine Diffuse_computeDt
  end interface

  interface
    subroutine Diffuse_finalize()
    end subroutine Diffuse_finalize
  end interface

  interface
    subroutine Diffuse_init(myPE)
      integer, intent(IN) :: myPE
    end subroutine Diffuse_init
  end interface

  interface
    subroutine Diffuse_species(sweepDir, igeom, blockID,numCells,blkLimits,blkLimitsGC,&
                               leftCoords,rightCoords,&
                               temp_flx, temp_fly, temp_flz)

      integer, intent(IN) :: sweepDir, igeom, blockID, numCells
      integer, dimension(2,MDIM), intent (IN) :: blkLimitsGC, blkLimits
  
  
      real, intent(INOUT), DIMENSION(NFLUXES,                   &
                                     blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS),     &
                                     blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS),     &
                                     blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)) ::  &
                                     temp_flx, temp_fly, temp_flz
  
      real, intent(IN), DIMENSION(numCells) :: leftCoords ,rightCoords
    end subroutine Diffuse_species
  end interface

  interface

    subroutine Diffuse_therm(sweepDir, igeom, blockID,numCells,blkLimits,blkLimitsGC,&
                             leftCoords,rightCoords,&
                             temp_flx, areaLeft)
      implicit none
      integer, intent(IN) :: sweepDir, igeom, blockID, numCells
      integer, dimension(2,MDIM), intent (IN) :: blkLimitsGC, blkLimits
  
#ifdef FIXEDBLOCKSIZE
      real, intent(INOUT), DIMENSION(NFLUXES,                 &
                               GRID_ILO_GC:GRID_IHI_GC,     &
                               GRID_JLO_GC:GRID_JHI_GC,     &
                               GRID_KLO_GC:GRID_KHI_GC) ::  &
                               temp_flx
      real, intent(IN), DIMENSION(                 &
                               GRID_ILO_GC:GRID_IHI_GC,     &
                               GRID_JLO_GC:GRID_JHI_GC,     &
                               GRID_KLO_GC:GRID_KHI_GC) ::  &
                               areaLeft
      real, intent(IN), DIMENSION(MAXCELLS) :: leftCoords ,rightCoords
#else
      real, intent(INOUT), DIMENSION(NFLUXES,                   &
                                     blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS),     &
                                     blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS),     &
                                     blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)) ::  &
                                     temp_flx
      real, intent(IN), DIMENSION(                   &
                                     blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS),     &
                                     blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS),     &
                                     blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)) ::  &
                                     areaLeft
      real, intent(IN), DIMENSION(numCells) :: leftCoords ,rightCoords
#endif
    end subroutine Diffuse_therm
  end interface

  interface
     subroutine Diffuse_visc(sweepDir, igeom, blockID,numCells,blkLimits,blkLimitsGC,&
                             leftCoords,rightCoords,&
                             temp_flx, areaLeft, secondCoord, thirdCoord)
       implicit none
       integer, intent(IN) :: sweepDir, igeom, blockID, numCells
       integer, dimension(2,MDIM), intent (IN) :: blkLimitsGC, blkLimits
  
#ifdef FIXEDBLOCKSIZE
       real, intent(INOUT), DIMENSION(NFLUXES,              &
                               GRID_ILO_GC:GRID_IHI_GC,     &
                               GRID_JLO_GC:GRID_JHI_GC,     &
                               GRID_KLO_GC:GRID_KHI_GC) ::  &
                               temp_flx
       real, intent(IN), DIMENSION(                         &
                               GRID_ILO_GC:GRID_IHI_GC,     &
                               GRID_JLO_GC:GRID_JHI_GC,     &
                               GRID_KLO_GC:GRID_KHI_GC) ::  &
                               areaLeft
       real, intent(IN), DIMENSION(MAXCELLS) :: leftCoords ,rightCoords, &
            secondCoord, thirdCoord
#else
       real, intent(INOUT), DIMENSION(NFLUXES,                   &
                               blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS),     &
                               blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS),     &
                               blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)) ::  &
                               temp_flx
       real, intent(IN), DIMENSION(                   &
                                   blkLimitsGC(LOW,IAXIS):blkLimitsGC(HIGH,IAXIS),     &
                                   blkLimitsGC(LOW,JAXIS):blkLimitsGC(HIGH,JAXIS),     &
                                   blkLimitsGC(LOW,KAXIS):blkLimitsGC(HIGH,KAXIS)) ::  &
                                   areaLeft
       real, intent(IN), DIMENSION(numCells) :: leftCoords ,rightCoords, &
            secondCoord, thirdCoord
#endif  
    end subroutine Diffuse_visc
  end interface

end Module Diffuse_interface
